========
 decmoc
========

.. image:: https://dl.dropbox.com/u/38476311/Logos/decmoc.png

The ancient boar-god of beating people over the head with heavy blunt instruments.

Also, a tool for declarative mocking with Mock_.

.. _Mock: http://www.voidspace.org.uk/python/mock/
